#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='mann_whitney',
    version='0.0.1',
    author='Mengyu_Liu',
    author_email='mengyu0520@gmail.com',
    url='https://github.com/Mengyuliu0520?tab=repositories',
    description=u'A implementation of Mann-Whitney test in Python',
    packages=['mann_whitney'],
    install_requires=[],
    python_requires='>=3.6'
)